# Notte Processing Pipelines

Each pipeline is a set of steps that are used to preprocess either a browser snapshot or a LLM observation.

Each file in this directory is a separate but mandatory in the global workflow.
